package com.goldencode.hotel.dmo.hotel.impl;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.hotel.dmo.hotel.*;

/**
 * Data Model Object corresponding with table <code>hotel.room_state</code> (previously
 * <code>hotel.room-state</code>).
 */
@LegacyTable(name = "room-state", table = "room_state")
public class RoomStateImpl
implements Serializable,
           Persistable,
           RoomState
{
   /** Surrogate primary key */
   private Long id = null;

   /** Room Number */
   @LegacyField(fieldId = 1, name = "room-number", format = ">>9", initial = "0", columnLabel = "Room Number", label = "Room Number", mandatory = true)
   private final integer roomNumber;

   /** Room State */
   @LegacyField(fieldId = 2, name = "state", format = "Active/Inactive", initial = "false", label = "Room State", mandatory = true)
   private final logical state;

   /** Date */
   @LegacyField(fieldId = 3, name = "start-date", format = "99/99/99", initial = "?", columnLabel = "Date", label = "Date")
   private final date startDate;

   /**
    * Default constructor.
    */
   public RoomStateImpl()
   {
      roomNumber = new integer(0);
      state = new logical(false);
      startDate = new date();
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new RoomStateImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from the given, backup
    * instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      RoomStateImpl from = (RoomStateImpl) old;
      setId(from.id);
      setRoomNumber(from.roomNumber);
      setState(from.state);
      setStartDate(from.startDate);
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: Room Number
    * 
    * @return  Room Number
    */
   public integer getRoomNumber()
   {
      return (new integer(roomNumber));
   }

   /**
    * Setter: Room Number
    * 
    * @param   roomNumber
    *          Room Number
    */
   public void setRoomNumber(NumberType roomNumber)
   {
      this.roomNumber.assign(roomNumber, true);
   }

   /**
    * Getter: Room State
    * 
    * @return  Room State
    */
   public logical isState()
   {
      return (new logical(state));
   }

   /**
    * Setter: Room State
    * 
    * @param   state
    *          Room State
    */
   public void setState(logical state)
   {
      this.state.assign(state, true);
   }

   /**
    * Getter: Date
    * 
    * @return  Date
    */
   public date getStartDate()
   {
      return (new date(startDate));
   }

   /**
    * Setter: Date
    * 
    * @param   startDate
    *          Date
    */
   public void setStartDate(date startDate)
   {
      this.startDate.assign(startDate, true);
   }
}
